@@ -216,7 +216,7 @@ public:
 	GCONF_KEY_PROXY_PORT = GCONF_KEY_WIRE_NAME + "/proxy_http_port";
 	//GCONF_KEY_PROXY_AUTH_PASS = GCONF_KEY_WIRE_NAME + "/authentication_password";
 	//GCONF_KEY_PROXY_AUTH_USER = GCONF_KEY_WIRE_NAME + "/authentication_user";
-	GCONF_KEY_PROXY_HOST = GCONF_KEY_WIRE_NAME + "/http_proxy";
+	GCONF_KEY_PROXY_HOST = GCONF_KEY_WIRE_NAME + "/proxy_http";
 	//GCONF_KEY_PROXY_USE_AUTH = GCONF_KEY_WIRE_NAME + "/use_authentication";
 	
 	//system proxy keys
